@@ -2,7 +2,7 @@ package Tie::Hash::Attribute;
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 our @ISA = 'Tie::Hash';
 
 our $ATTR_SORT = 0;
@@ -110,8 +110,9 @@ Tie::Hash::Attribute - Just another HTML attribute generator.
           style => {
               align => [qw( left right )],
               color => [qw( red blue green )],
+          }
       },
-  };
+  );
  
   print $tag{-table};
     # border: 0
@@ -127,8 +128,16 @@ Tie::Hash::Attribute - Just another HTML attribute generator.
 
   # or emit all attributes at once
   tie my %tr_tag, 'Tie::Hash::Attribute';
-  %tr_tag = ( style => { color => [qw(red blue green)] } );
-  print scalar %tr_tag;
+
+  %tr_tag = ( style => {
+      align => [qw(left right)],
+      color => [qw(red blue green)]
+  } );
+
+  print scalar %tr_tag for 1 .. 4;
+    # style="align: left; color: red;"
+    # style="align: right; color: blue;"
+    # style="align: left; color: green;"
     # style="align: right; color: red;"
 
 =head1 DESCRIPTION
@@ -268,7 +277,7 @@ Jeff Anderson, C<< <jeffa at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Jeff Anderson.
+Copyright 2016 Jeff Anderson.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
